@@ -9,8 +9,9 @@ class CompositeAnimationManager(object):
         self._animations.append((animation, widget))
 
     def _anim_done_handler(self, anim, widget):
+        anim.cancel(widget)
         self._animations.remove((anim, widget))
-        if not self._animations:
+        if len(self._animations) == 0:
             self._finish_handler()
 
     def when_done(self, handler):
