@@ -7,10 +7,13 @@ import tempfile
 from appdirs import user_cache_dir
 from twisted.internet import reactor
 from .structure import BaseGuiStructureMixin
+from .widgets.colors import GuiPalette
 
 
 class BaseMixin(object):
     _appname = 'iotnode'
+    _app_root = os.path.abspath(os.path.dirname(__file__))
+    _app_resources = os.path.join(_app_root, 'resources')
 
     def __init__(self, *args, **kwargs):
         self._reactor = kwargs.pop('reactor', reactor)
@@ -19,6 +22,10 @@ class BaseMixin(object):
         self._temp_dir = None
         super(BaseMixin, self).__init__(*args, **kwargs)
 
+    @property
+    def app_resources(self):
+        return self._app_resources
+
     def start(self):
         pass
 
@@ -62,16 +69,28 @@ class BaseMixin(object):
 
 
 class BaseGuiMixin(BaseGuiStructureMixin):
-    _gui_color_1 = (0xff / 255, 0xff / 255, 0xff / 255)
-    _gui_color_2 = (0xff / 255, 0xff / 255, 0xff / 255)
+    _palette = GuiPalette(
+        background=(0x00 / 255, 0x00 / 255, 0x00 / 255),
+        foreground=(0xff / 255, 0xff / 255, 0xff / 255),
+        color_1=(0xff / 255, 0xff / 255, 0xff / 255),
+        color_2=(0xff / 255, 0xff / 255, 0xff / 255)
+    )
 
     def gui_setup(self):
         pass
 
     @property
     def gui_color_1(self):
-        return self._gui_color_1
+        return self._palette.color_1
 
     @property
     def gui_color_2(self):
-        return self._gui_color_2
+        return self._palette.color_2
+
+    @property
+    def gui_color_foreground(self):
+        return self._palette.foreground
+
+    @property
+    def gui_color_background(self):
+        return self._palette.background
